#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yaml
version:              0.11.11.2
visibility:           public
id:                   yaml-0.11.11.2-3BCv4CO4LZa5ROi1TocCLv
key:                  yaml-0.11.11.2-3BCv4CO4LZa5ROi1TocCLv
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  297f19b236c0fc9f395b89f27660f0c7
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yaml
hs-libraries:         HSyaml-0.11.11.2-3BCv4CO4LZa5ROi1TocCLv
depends:
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie
    attoparsec-0.14.4-8Ihrc92tki9CPtxJ7iMWhq base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-8P16HBmakUKG1It6ArZYEY
    containers-0.6.7 directory-1.3.8.5 filepath-1.4.300.1
    libyaml-0.1.4-6JjV2TVeWAJ4eZCqPOlK0j mtl-2.3.1
    resourcet-1.2.6-G3oEY3e1QnrAdomD3ZD7m7
    scientific-0.3.8.1-9lNiUg0NFGt8fB4Ap5FVsD template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-HfKtyefgs0b2egKrxLGXU0
    vector-0.13.2.0-7eILYIgfGZSAohY3MIpZY

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

